DurationKnobConfig class

Inheritance

Constructors

DurationKnobConfig(String label, int durationInMilliseconds)
Creates a new KnobConfig for knobs.duration.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
The knob's label.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The value of the entry must be a query string that can be parsed by the knob. The easiest way to get the value is to use the URL query string of a Widgetbook web build.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMapEntry() MapEntry<String, int>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited