KnobConfig<T> class
Constructors
- KnobConfig(String label, T value)
-
Creates a new KnobConfig using a
labeland avalue.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
The knob's label.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
The value of the entry must be a query string that can be parsed by the
knob. The easiest way to get the value is to use the URL query string
of a Widgetbook web build.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMapEntry(
) → MapEntry< String, T> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- nullabilitySymbol → const String