value property

T value
final

The value of the entry must be a query string that can be parsed by the knob. The easiest way to get the value is to use the URL query string of a Widgetbook web build.

Implementation

final T value;