menu
widgetbook_annotation package
documentation
widgetbook_annotation.dart
ListKnobConfig class
ListKnobConfig class
dark_mode
light_mode
ListKnobConfig
class
Inheritance
Object
KnobConfig
<
String
>
ListKnobConfig
Annotations
@
Deprecated
('Use `ObjectKnobConfig` instead.')
Constructors
ListKnobConfig
(
String
label
,
String
itemLabel
)
Creates a new
KnobConfig
for
knobs.list
. The easiest way to get the
itemLabel
is to check the URL query string of a Widgetbook web build.
const
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
label
→
String
The knob's label.
final
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
value
→
String
The value of the entry must be a query string that can be parsed by the knob. The easiest way to get the value is to use the URL query string of a Widgetbook web build.
final
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMapEntry
(
)
→
MapEntry
<
String
,
String
>
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
widgetbook_annotation package
documentation
widgetbook_annotation
ListKnobConfig class
widgetbook_annotation library