ObjectKnobConfig class
Constructors
ObjectKnobConfig (String label , String objectLabel )
Creates a new KnobConfig for knobs.object.
The easiest way to get the objectLabel is to check the
URL query string of a Widgetbook web build.
const
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
label
→ String
The knob's label.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
value
→ String
The value of the entry must be a query string that can be parsed by the
knob. The easiest way to get the value is to use the URL query string
of a Widgetbook web build.
final inherited
widgetbook_annotation 3.11.0