WidgetbookApp class

Annotates a code element to create the widgetbook main file in the same folder in which the annotated element is defined.

Constructors

WidgetbookApp({required String name, required Type themeType, List<Device> devices = const <Device>[], List<WidgetbookFrame> frames = const <WidgetbookFrame>[], List<double> textScaleFactors = const <double>[], bool foldersExpanded = false, bool widgetsExpanded = false, WidgetbookConstructor constructor = WidgetbookConstructor.custom})
Creates a new annotation with name and optional devices. If devices is not set or set to an empty list, no code for the Widgetbook.devices property will be generated. Therefore, the default of Widgetbook will be used.
const
WidgetbookApp.cupertino({required String name, List<Device> devices = const <Device>[], List<WidgetbookFrame> frames = const <WidgetbookFrame>[], List<double> textScaleFactors = const <double>[], bool foldersExpanded = false, bool widgetsExpanded = false, WidgetbookConstructor constructor = WidgetbookConstructor.cupertino})
Annotates a code element to creat a Cupertino-themed widgetbook main file in the same folder in which the annotated element is defined.
const
WidgetbookApp.material({required String name, List<Device> devices = const <Device>[], List<WidgetbookFrame> frames = const <WidgetbookFrame>[], List<double> textScaleFactors = const <double>[], bool foldersExpanded = false, bool widgetsExpanded = false, WidgetbookConstructor constructor = WidgetbookConstructor.material})
Annotates a code element to creat a Material-themed widgetbook main file in the same folder in which the annotated element is defined.
const

Properties

constructor WidgetbookConstructor
Indicates which type of theme is used for the generic Widgetbook implementation.
final
devices List<Device>
The devices shown in the Widgetbook
final
foldersExpanded bool
Determines folders are expanded by default
final
frames List<WidgetbookFrame>
The device frames shown in the Widgetbook
final
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the widgetbook. This information will be displayed at the top left corner in the UI.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textScaleFactors List<double>
A list of text scale factors
final
themeType Type?
The type of the ThemeData.
final
widgetsExpanded bool
Determines widgets are expanded by default
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited