MultiFieldKnobConfig class
Constructors
-
MultiFieldKnobConfig(Map<String, dynamic> fields)
-
All first-class knobs provided by Widgetbook are single-field knobs.
This means that they have only one field. For example, the
knobs.int
knob has only one IntField.
const
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
label
→ String
-
The knob's label.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ Map<String, dynamic>
-
The value of the entry must be a query string that can be parsed by the
knob. The easiest way to get the value is to use the URL query string
of a Widgetbook web build.
finalinherited